@@ -1,16 +1,14 @@
 #ABSTRACT: list fees
 package App::PAIA::Command::fees;
-use base 'App::PAIA::Command';
-use v5.14;
-our $VERSION = '0.11'; #VERSION
+use strict;
+use v5.10;
+use parent 'App::PAIA::Command';
+our $VERSION = '0.20'; #VERSION
 
-use App::PAIA::JSON;
-
-sub execute {
+sub _execute {
     my ($self, $opt, $args) = @_;
 
-    my $response = $self->core_request('GET', 'fees');
-    print encode_json($response);
+    $self->core_request('GET', 'fees');
 }
 
 1;
@@ -26,7 +24,7 @@ App::PAIA::Command::fees - list fees
 
 =head1 VERSION
 
-version 0.11
+version 0.20
 
 =head1 AUTHOR
 
