@@ -1,32 +1,26 @@
 #ABSTRACT: show current session status
 package App::PAIA::Command::session;
+use strict;
+use v5.10;
 use parent 'App::PAIA::Command';
-use v5.14;
-our $VERSION = '0.11'; #VERSION
+our $VERSION = '0.20'; #VERSION
 
 use App::PAIA::JSON;
 
 sub description {
 <<MSG
-This command shows the current PAIA auth session and configuration.
+This command shows the current PAIA auth session.
 The exit code indicates whether a session file was found with not-expired
 access token and PAIA server URLs. Options --verbose|-v enables details.
 MSG
 }
 
-sub execute {
+sub _execute {
     my ($self, $opt, $args) = @_;
 
-    if ($self->verbose) {
-        if (defined $self->config_file) {
-            $self->log("configuration in ".$self->config_file.":");
-            print encode_json($self->config);
-        }
-    }
-    
-    if (defined $self->session_file ) {
-        $self->log("session in ".$self->session_file.":");
-        say encode_json($self->session) if $self->verbose;
+    if (defined $self->session->file ) {
+        my $data = $self->session->load;
+        say encode_json($data) if $self->verbose;
         my $msg = $self->not_authentificated;
         die "$msg.\n" if $msg;
         say "session looks fine.";
@@ -45,6 +39,8 @@ sub execute {
     } else {
         $self->log('core URL: '.$self->core);
     }
+
+    return;
 }
 
 1;
@@ -60,7 +56,7 @@ App::PAIA::Command::session - show current session status
 
 =head1 VERSION
 
-version 0.11
+version 0.20
 
 =head1 AUTHOR
 
